--
-- Results Database Schema
-- Date Created : Thursday, April 30, 2009 09:11:38
-- Target DBMS : MySQL 5.x
--

CREATE TABLE `actiontype`(
    `id`        BIGINT         AUTO_INCREMENT,
    `uniqueid`  VARCHAR(32)    NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `actiontype_uidx`(`uniqueid`)
)ENGINE=INNODB
;



CREATE TABLE `appmodeltype`(
    `id`        BIGINT         AUTO_INCREMENT,
    `uniqueid`  VARCHAR(64)    NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `appmodeltype_uidx`(`uniqueid`)
)ENGINE=INNODB
;



CREATE TABLE `project`(
    `id`        BIGINT          AUTO_INCREMENT,
    `uniqueid`  CHAR(36)        NOT NULL,
    `name`      VARCHAR(255)    NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `project_uidx`(`uniqueid`)
)ENGINE=INNODB
;



CREATE TABLE `appmodelitem`(
    `id`               BIGINT          AUTO_INCREMENT,
    `parent_id`        BIGINT,
    `appmodeltype_id`  BIGINT          NOT NULL,
    `project_id`       BIGINT          NOT NULL,
    `uniqueid`         VARCHAR(255)    NOT NULL,
    `display`          VARCHAR(255),
    `archived`         CHAR(1)         DEFAULT 'N',
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `project_id`(`project_id`, `uniqueid`),
    INDEX `parent_id`(`parent_id`),
    INDEX `appmodeltype_id`(`appmodeltype_id`), 
    FOREIGN KEY (`appmodeltype_id`)
    REFERENCES `appmodeltype`(`id`),
    FOREIGN KEY (`project_id`)
    REFERENCES `project`(`id`),
    FOREIGN KEY (`parent_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `action`(
    `id`               BIGINT          AUTO_INCREMENT,
    `appmodelitem_id`  BIGINT          NOT NULL,
    `uniqueid`         VARCHAR(32)     NOT NULL,
    `actiontype_id`    BIGINT          NOT NULL,
    `display`          VARCHAR(128),
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `appmodelitem_id`(`appmodelitem_id`, `uniqueid`),
    INDEX `actiontype_id`(`actiontype_id`), 
    FOREIGN KEY (`actiontype_id`)
    REFERENCES `actiontype`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `action_execution`(
    `id`         BIGINT      AUTO_INCREMENT,
    `action_id`  BIGINT,
    `parent_id`  BIGINT,
    `expected`   LONGBLOB,
    `received`   LONGBLOB,
    `console`    LONGBLOB,
    PRIMARY KEY (`id`), 
    INDEX `ref7577`(`action_id`),
    INDEX `ref7681`(`parent_id`), 
    FOREIGN KEY (`action_id`)
    REFERENCES `action`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`parent_id`)
    REFERENCES `action_execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;

CREATE TABLE `agent`(
    `id`   BIGINT          AUTO_INCREMENT,
    `url`  VARCHAR(100)    NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `agent_uni`(`url`)
)ENGINE=INNODB
;



CREATE TABLE `bwhost_mrv`(
    `id`            BIGINT          AUTO_INCREMENT,
    `hostname`      VARCHAR(256)    NOT NULL,
    `instancename`  VARCHAR(256)    NOT NULL,
    `ipaddress`     VARCHAR(256)    NOT NULL,
    `domain`        VARCHAR(256)    NOT NULL,
    `time`          BIGINT          NOT NULL,
    `numproc`       BIGINT,
    PRIMARY KEY (`id`), 
    INDEX `bwhost_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `bwactivity_mrv`(
    `id`               BIGINT          AUTO_INCREMENT,
    `bwhost_mrv_id`    BIGINT          NOT NULL,
    `activityname`     VARCHAR(256)    NOT NULL,
    `processname`      VARCHAR(256)    NOT NULL,
    `activity_class`   VARCHAR(256)    NOT NULL,
    `time`             BIGINT          NOT NULL,
    `execution_count`  BIGINT,
    `error_count`      BIGINT,
    `elapsed_time`     BIGINT,
    `execution_time`   BIGINT,
    `min_elapsed`      BIGINT,
    `max_elapsed`      BIGINT,
    `min_exec`         BIGINT,
    `max_exec`         BIGINT,
    `average_exec`     BIGINT,
    `average_elapsed`  BIGINT,
    PRIMARY KEY (`id`), 
    INDEX `bwactivity_mrv_index1`(`time`),
    INDEX `sys_c004265`(`bwhost_mrv_id`), 
    FOREIGN KEY (`bwhost_mrv_id`)
    REFERENCES `bwhost_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `status`(
    `id`       BIGINT         AUTO_INCREMENT,
    `display`  VARCHAR(10),
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `statux_uidx`(`display`)
)ENGINE=INNODB
;



CREATE TABLE `execution`(
    `id`          BIGINT    AUTO_INCREMENT,
    `parent_id`   BIGINT,
    `start_time`  BIGINT    NOT NULL,
    `end_time`    BIGINT,
    `duration`    BIGINT,
    `status_id`   BIGINT,
    `root_id`     BIGINT,
    `environment` BIGINT,
    PRIMARY KEY (`id`), 
    INDEX `parent_id`(`parent_id`), 
    FOREIGN KEY (`parent_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`status_id`)
    REFERENCES `status`(`id`),
    CONSTRAINT execution_rootid_fk
    FOREIGN KEY (root_id)
    REFERENCES execution(id),
    CONSTRAINT execution_environment_fk
    FOREIGN KEY (environment) 
    REFERENCES appmodelitem(id)
)ENGINE=INNODB
;



CREATE TABLE `bwactivity_ts`(
    `idx`                BIGINT    NOT NULL,
    `bwactivity_mrv_id`  BIGINT    NOT NULL,
    `execution_id`       BIGINT,
    `time`               BIGINT    NOT NULL,
    `execution_count`    BIGINT,
    `error_count`        BIGINT,
    `elapsed_time`       BIGINT,
    `execution_time`     BIGINT,
    `min_elapsed`        BIGINT,
    `max_elapsed`        BIGINT,
    `min_exec`           BIGINT,
    `max_exec`           BIGINT,
    `average_exec`       BIGINT,
    `average_elapsed`    BIGINT,
    INDEX `bwactivity_ts_index2`(`execution_id`),
    INDEX `bwactivity_ts_index1`(`time`),
    INDEX `sys_c004270`(`bwactivity_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`bwactivity_mrv_id`)
    REFERENCES `bwactivity_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `bwhost_ts`(
    `idx`            BIGINT    NOT NULL,
    `bwhost_mrv_id`  BIGINT    NOT NULL,
    `execution_id`   BIGINT,
    `time`           BIGINT    NOT NULL,
    `numproc`        BIGINT,
    INDEX `bwhost_ts_index2`(`execution_id`),
    INDEX `bwhost_ts_index1`(`time`),
    INDEX `sys_c004246`(`bwhost_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`bwhost_mrv_id`)
    REFERENCES `bwhost_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `bwproc_mrv`(
    `id`               BIGINT          AUTO_INCREMENT,
    `bwhost_mrv_id`    BIGINT          NOT NULL,
    `processname`      VARCHAR(256)    NOT NULL,
    `time`             BIGINT          NOT NULL,
    `startername`      VARCHAR(256),
    `created`          BIGINT,
    `suspended`        BIGINT,
    `swapped`          BIGINT,
    `queued`           BIGINT,
    `aborted`          BIGINT,
    `completed`        BIGINT,
    `average_exec`     BIGINT,
    `average_elapsed`  BIGINT,
    `min_elapsed`      BIGINT,
    `max_elapsed`      BIGINT,
    `min_exec`         BIGINT,
    `max_exec`         BIGINT,
    `creation_rate`    BIGINT,
    `running`          BIGINT,
    PRIMARY KEY (`id`), 
    INDEX `bwproc_mrv_index1`(`time`),
    INDEX `sys_c004252`(`bwhost_mrv_id`), 
    FOREIGN KEY (`bwhost_mrv_id`)
    REFERENCES `bwhost_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `bwproc_ts`(
    `idx`              BIGINT    NOT NULL,
    `bwproc_mrv_id`    BIGINT    NOT NULL,
    `execution_id`     BIGINT,
    `time`             BIGINT    NOT NULL,
    `created`          BIGINT,
    `suspended`        BIGINT,
    `swapped`          BIGINT,
    `queued`           BIGINT,
    `aborted`          BIGINT,
    `completed`        BIGINT,
    `average_exec`     BIGINT,
    `average_elapsed`  BIGINT,
    `min_elapsed`      BIGINT,
    `max_elapsed`      BIGINT,
    `min_exec`         BIGINT,
    `max_exec`         BIGINT,
    `creation_rate`    BIGINT,
    `running`          BIGINT,
    INDEX `bwproc_ts_index2`(`execution_id`),
    INDEX `bwproc_ts_index1`(`time`),
    INDEX `sys_c004257`(`bwproc_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`bwproc_mrv_id`)
    REFERENCES `bwproc_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `counter_details`(
    `id`    BIGINT          AUTO_INCREMENT,
    `name`  VARCHAR(255)    NOT NULL,
    `type`  VARCHAR(20)     NOT NULL,
    PRIMARY KEY (`id`)
)ENGINE=INNODB
;



CREATE TABLE `coverage`(
    `id`            BIGINT         AUTO_INCREMENT,
    `execution_id`  BIGINT         NOT NULL,
    `type`          VARCHAR(10)    NOT NULL,
    `bin`           LONGBLOB,
    PRIMARY KEY (`id`), 
    INDEX `ref81130`(`execution_id`), 
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `db_details`(
    `ctime`     DATETIME        NOT NULL,
    `property`  VARCHAR(100)    NOT NULL,
    `value`     VARCHAR(100)    NOT NULL
)ENGINE=INNODB
;



CREATE TABLE `detail_execution`(
    `execution_id`         BIGINT          NOT NULL,
    `appmodelitem_id`      BIGINT          NOT NULL,
    `action_execution_id`  BIGINT,
    `username`             VARCHAR(50),
    `hostname`             VARCHAR(100),
    `total_iterations`     BIGINT,
    `failed_iterations`    VARCHAR(500),
    `failed_count`         BIGINT,
    PRIMARY KEY (`execution_id`), 
    INDEX `appmodelitem_id`(`appmodelitem_id`),
    INDEX `action_execution_id`(`action_execution_id`), 
    FOREIGN KEY (`action_execution_id`)
    REFERENCES `action_execution`(`id`),
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `dqgroup_mrv`(
    `id`        BIGINT          AUTO_INCREMENT,
    `dqname`    VARCHAR(100)    NOT NULL,
    `grp`       VARCHAR(30)     NOT NULL,
    `time`      BIGINT          NOT NULL,
    `hostip`    VARCHAR(20)     NOT NULL,
    `hostname`  VARCHAR(50)     NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `dqgroup_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `dqgroup_ts`(
    `idx`             BIGINT    NOT NULL,
    `dqgroup_mrv_id`  BIGINT    NOT NULL,
    `execution_id`    BIGINT,
    `time`            BIGINT    NOT NULL,
    `accepted`        BIGINT    NOT NULL,
    `completed`       BIGINT    NOT NULL,
    `rejected`        BIGINT    NOT NULL,
    INDEX `dqgroup_ts_index2`(`execution_id`),
    INDEX `dqgroup_ts_index1`(`time`),
    INDEX `sys_c004478`(`dqgroup_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`dqgroup_mrv_id`)
    REFERENCES `dqgroup_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `dqmember_mrv`(
    `id`              BIGINT          AUTO_INCREMENT,
    `dqgroup_mrv_id`  BIGINT          NOT NULL,
    `membertag`       VARCHAR(20)     NOT NULL,
    `time`            BIGINT          NOT NULL,
    `memberid`        VARCHAR(100)    NOT NULL,
    `hostip`          VARCHAR(20)     NOT NULL,
    `hostname`        VARCHAR(50)     NOT NULL,
    `type`            VARCHAR(10)     NOT NULL,
    `weight`          BIGINT          NOT NULL,
    `maxtasks`        BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `dqmember_mrv_index1`(`time`),
    INDEX `sys_c004490`(`dqgroup_mrv_id`), 
    FOREIGN KEY (`dqgroup_mrv_id`)
    REFERENCES `dqgroup_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `dqmember_ts`(
    `idx`              BIGINT    NOT NULL,
    `dqmember_mrv_id`  BIGINT    NOT NULL,
    `execution_id`     BIGINT,
    `time`             BIGINT    NOT NULL,
    `accepted`         BIGINT    NOT NULL,
    `completed`        BIGINT    NOT NULL,
    `rejected`         BIGINT    NOT NULL,
    INDEX `dqmember_ts_index1`(`time`),
    INDEX `dqmember_ts_index2`(`execution_id`),
    INDEX `sys_c004498`(`dqmember_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`dqmember_mrv_id`)
    REFERENCES `dqmember_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `dt`(
    `id`            BIGINT         AUTO_INCREMENT,
    `name`          VARCHAR(50)    NOT NULL,
    `execution_id`  BIGINT         NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `dt_uni`(`id`),
    INDEX `ref3186`(`execution_id`), 
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `dt_history`(
    `id`        BIGINT    AUTO_INCREMENT,
    `dt_id`     BIGINT,
    `agent_id`  BIGINT    NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `dt_history_idx1`(`dt_id`),
    INDEX `ref1145`(`agent_id`), 
    FOREIGN KEY (`agent_id`)
    REFERENCES `agent`(`id`),
    FOREIGN KEY (`dt_id`)
    REFERENCES `dt`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `ems_server_mrv`(
    `id`            BIGINT          AUTO_INCREMENT,
    `broker`        VARCHAR(50)     NOT NULL,
    `time`          BIGINT          NOT NULL,
    `status`        VARCHAR(10)     NOT NULL,
    `cfg`           VARCHAR(50)     NOT NULL,
    `strt`          BIGINT          NOT NULL,
    `state`         VARCHAR(20)     NOT NULL,
    `up`            BIGINT          NOT NULL,
    `url`           VARCHAR(20)     NOT NULL,
    `hostip`        VARCHAR(20)     NOT NULL,
    `ver`           VARCHAR(20)     NOT NULL,
    `lic`           VARCHAR(20)     NOT NULL,
    `maxconn`       BIGINT          NOT NULL,
    `asm`           BIGINT          NOT NULL,
    `msgdskrr`      BIGINT          NOT NULL,
    `msgdskwr`      BIGINT          NOT NULL,
    `minastore`     BIGINT          NOT NULL,
    `storedir`      VARCHAR(40)     NOT NULL,
    `minstore`      BIGINT          NOT NULL,
    `syncmgrsz`     BIGINT          NOT NULL,
    `fsync`         CHAR(1)         NOT NULL,
    `trunc`         CHAR(1)         NOT NULL,
    `filttype`      VARCHAR(20)     NOT NULL,
    `filtval`       VARCHAR(20),
    `tracetarg`     VARCHAR(20)     NOT NULL,
    `hbwait`        BIGINT          NOT NULL,
    `secreadfiles`  CHAR(1)         NOT NULL,
    `hbmsglen`      BIGINT          NOT NULL,
    `rectimeout`    BIGINT          NOT NULL,
    `logmaxsz`      BIGINT          NOT NULL,
    `logfile`       VARCHAR(20),
    `logsz`         VARCHAR(20)     NOT NULL,
    `logtrace`      VARCHAR(100)    NOT NULL,
    `contrace`      VARCHAR(100)    NOT NULL,
    `maxmsgmem`     BIGINT          NOT NULL,
    `maxstatsmem`   BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `ems_server_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `ems_queue_mrv`(
    `id`                 BIGINT          AUTO_INCREMENT,
    `ems_server_mrv_id`  BIGINT          NOT NULL,
    `name`               VARCHAR(100)    NOT NULL,
    `time`               BIGINT          NOT NULL,
    `istemp`             CHAR(1)         NOT NULL,
    `isstatic`           CHAR(1)         NOT NULL,
    `pmc`                BIGINT          NOT NULL,
    `pms`                BIGINT          NOT NULL,
    `imr`                BIGINT          NOT NULL,
    `omr`                BIGINT          NOT NULL,
    `ibr`                BIGINT          NOT NULL,
    `obr`                BIGINT          NOT NULL,
    `imc`                BIGINT          NOT NULL,
    `omc`                BIGINT          NOT NULL,
    `ibc`                BIGINT          NOT NULL,
    `obc`                BIGINT          NOT NULL,
    `dmc`                BIGINT          NOT NULL,
    `tmc`                BIGINT          NOT NULL,
    `arc`                BIGINT          NOT NULL,
    `cc`                 BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `ems_queue_mrv_index1`(`time`),
    INDEX `sys_c004385`(`ems_server_mrv_id`), 
    FOREIGN KEY (`ems_server_mrv_id`)
    REFERENCES `ems_server_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `ems_queue_ts`(
    `idx`               BIGINT    NOT NULL,
    `ems_queue_mrv_id`  BIGINT    NOT NULL,
    `execution_id`      BIGINT,
    `time`              BIGINT    NOT NULL,
    `pmc`               BIGINT    NOT NULL,
    `pms`               BIGINT    NOT NULL,
    `imr`               BIGINT    NOT NULL,
    `omr`               BIGINT    NOT NULL,
    `ibr`               BIGINT    NOT NULL,
    `obr`               BIGINT    NOT NULL,
    `imc`               BIGINT    NOT NULL,
    `omc`               BIGINT    NOT NULL,
    `ibc`               BIGINT    NOT NULL,
    `obc`               BIGINT    NOT NULL,
    `dmc`               BIGINT    NOT NULL,
    `tmc`               BIGINT    NOT NULL,
    `arc`               BIGINT    NOT NULL,
    `cc`                BIGINT    NOT NULL,
    INDEX `ems_queue_ts_index1`(`time`),
    INDEX `ems_queue_ts_index2`(`execution_id`),
    INDEX `sys_c004404`(`ems_queue_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ems_queue_mrv_id`)
    REFERENCES `ems_queue_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `ems_route_mrv`(
    `id`                 BIGINT          AUTO_INCREMENT,
    `ems_server_mrv_id`  BIGINT          NOT NULL,
    `remoteserver`       VARCHAR(100)    NOT NULL,
    `time`               BIGINT          NOT NULL,
    `remoteurl`          VARCHAR(100)    NOT NULL,
    `zone`               VARCHAR(100)    NOT NULL,
    `zonetype`           VARCHAR(20)     NOT NULL,
    `imr`                BIGINT          NOT NULL,
    `omr`                BIGINT          NOT NULL,
    `ibr`                BIGINT          NOT NULL,
    `obr`                BIGINT          NOT NULL,
    `imc`                BIGINT          NOT NULL,
    `omc`                BIGINT          NOT NULL,
    `ibc`                BIGINT          NOT NULL,
    `obc`                BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `ems_route_mrv_index1`(`time`),
    INDEX `sys_c004421`(`ems_server_mrv_id`), 
    FOREIGN KEY (`ems_server_mrv_id`)
    REFERENCES `ems_server_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `ems_route_ts`(
    `idx`               BIGINT    NOT NULL,
    `ems_route_mrv_id`  BIGINT    NOT NULL,
    `execution_id`      BIGINT,
    `time`              BIGINT    NOT NULL,
    `imr`               BIGINT    NOT NULL,
    `omr`               BIGINT    NOT NULL,
    `ibr`               BIGINT    NOT NULL,
    `obr`               BIGINT    NOT NULL,
    `imc`               BIGINT    NOT NULL,
    `omc`               BIGINT    NOT NULL,
    `ibc`               BIGINT    NOT NULL,
    `obc`               BIGINT    NOT NULL,
    INDEX `ems_route_ts_index1`(`time`),
    INDEX `ems_route_ts_index2`(`execution_id`),
    INDEX `sys_c004434`(`ems_route_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ems_route_mrv_id`)
    REFERENCES `ems_route_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `ems_server_ts`(
    `idx`                BIGINT    NOT NULL,
    `ems_server_mrv_id`  BIGINT    NOT NULL,
    `execution_id`       BIGINT,
    `time`               BIGINT    NOT NULL,
    `totalconn`          BIGINT    NOT NULL,
    `durconn`            BIGINT    NOT NULL,
    `msgmem`             BIGINT    NOT NULL,
    `msgmempooled`       BIGINT    NOT NULL,
    `obr`                BIGINT    NOT NULL,
    `ibr`                BIGINT    NOT NULL,
    `omr`                BIGINT    NOT NULL,
    `omc`                BIGINT    NOT NULL,
    `imr`                BIGINT    NOT NULL,
    `imc`                BIGINT    NOT NULL,
    `pmc`                BIGINT    NOT NULL,
    `pms`                BIGINT    NOT NULL,
    `qc`                 BIGINT    NOT NULL,
    `tc`                 BIGINT    NOT NULL,
    INDEX `ems_server_ts_index1`(`time`),
    INDEX `ems_server_ts_index2`(`execution_id`),
    INDEX `sys_c004324`(`ems_server_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ems_server_mrv_id`)
    REFERENCES `ems_server_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `ems_topic_mrv`(
    `id`                 BIGINT          AUTO_INCREMENT,
    `ems_server_mrv_id`  BIGINT          NOT NULL,
    `name`               VARCHAR(100)    NOT NULL,
    `time`               BIGINT          NOT NULL,
    `istemp`             CHAR(1)         NOT NULL,
    `isstatic`           CHAR(1)         NOT NULL,
    `pmc`                BIGINT          NOT NULL,
    `pms`                BIGINT          NOT NULL,
    `imr`                BIGINT          NOT NULL,
    `omr`                BIGINT          NOT NULL,
    `ibr`                BIGINT          NOT NULL,
    `obr`                BIGINT          NOT NULL,
    `imc`                BIGINT          NOT NULL,
    `omc`                BIGINT          NOT NULL,
    `ibc`                BIGINT          NOT NULL,
    `obc`                BIGINT          NOT NULL,
    `dc`                 BIGINT          NOT NULL,
    `adc`                BIGINT          NOT NULL,
    `sc`                 BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `ems_topic_mrv_index1`(`time`),
    INDEX `sys_c004345`(`ems_server_mrv_id`), 
    FOREIGN KEY (`ems_server_mrv_id`)
    REFERENCES `ems_server_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `ems_topic_ts`(
    `idx`               BIGINT    NOT NULL,
    `ems_topic_mrv_id`  BIGINT    NOT NULL,
    `execution_id`      BIGINT,
    `time`              BIGINT    NOT NULL,
    `pmc`               BIGINT    NOT NULL,
    `pms`               BIGINT    NOT NULL,
    `imr`               BIGINT    NOT NULL,
    `omr`               BIGINT    NOT NULL,
    `ibr`               BIGINT    NOT NULL,
    `obr`               BIGINT    NOT NULL,
    `imc`               BIGINT    NOT NULL,
    `omc`               BIGINT    NOT NULL,
    `ibc`               BIGINT    NOT NULL,
    `obc`               BIGINT    NOT NULL,
    `dc`                BIGINT    NOT NULL,
    `adc`               BIGINT    NOT NULL,
    `sc`                BIGINT    NOT NULL,
    INDEX `ems_topic_ts_index1`(`time`),
    INDEX `ems_topic_ts_index2`(`execution_id`),
    INDEX `sys_c004363`(`ems_topic_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ems_topic_mrv_id`)
    REFERENCES `ems_topic_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `flex_type`(
    `pk`    BIGINT          AUTO_INCREMENT,
    `data`  VARCHAR(255),
    PRIMARY KEY (`pk`), 
    UNIQUE INDEX `flex_type_index1`(`data`)
)ENGINE=INNODB
;



CREATE TABLE `flex_method`(
    `pk`    BIGINT          AUTO_INCREMENT,
    `type`  BIGINT          NOT NULL,
    `data`  VARCHAR(255),
    PRIMARY KEY (`pk`), 
    UNIQUE INDEX `flex_method_index1`(`type`, `data`), 
    FOREIGN KEY (`type`)
    REFERENCES `flex_type`(`pk`)
)ENGINE=INNODB
;



CREATE TABLE `flex_col`(
    `pk`      BIGINT          AUTO_INCREMENT,
    `method`  BIGINT          NOT NULL,
    `data`    VARCHAR(255),
    PRIMARY KEY (`pk`), 
    UNIQUE INDEX `flex_col_index1`(`method`, `data`), 
    FOREIGN KEY (`method`)
    REFERENCES `flex_method`(`pk`)
)ENGINE=INNODB
;



CREATE TABLE `flex_event`(
    `pk`               BIGINT    AUTO_INCREMENT,
    `millis_1970_utc`  BIGINT    NOT NULL,
    `instance`         BIGINT,
    PRIMARY KEY (`pk`), 
    INDEX `flex_event_index1`(`millis_1970_utc`)
)ENGINE=INNODB
;



CREATE TABLE `flex_row`(
    `pk`    BIGINT          AUTO_INCREMENT,
    `col`   BIGINT          NOT NULL,
    `data`  VARCHAR(255),
    PRIMARY KEY (`pk`), 
    UNIQUE INDEX `flex_row_index1`(`col`, `data`), 
    FOREIGN KEY (`col`)
    REFERENCES `flex_col`(`pk`)
)ENGINE=INNODB
;



CREATE TABLE `flex_double`(
    `pk`     BIGINT           AUTO_INCREMENT,
    `row_`   BIGINT           NOT NULL,
    `event`  BIGINT           NOT NULL,
    `data`   DOUBLE(53, 0)    NOT NULL,
    PRIMARY KEY (`pk`), 
    INDEX `flex_double_index1`(`row_`, `event`),
    INDEX `event`(`event`), 
    FOREIGN KEY (`event`)
    REFERENCES `flex_event`(`pk`),
    FOREIGN KEY (`row_`)
    REFERENCES `flex_row`(`pk`)
)ENGINE=INNODB
;



CREATE TABLE `flex_long`(
    `pk`     BIGINT    AUTO_INCREMENT,
    `row_`   BIGINT    NOT NULL,
    `event`  BIGINT    NOT NULL,
    `data`   BIGINT    NOT NULL,
    PRIMARY KEY (`pk`), 
    INDEX `flex_long_index1`(`row_`, `event`),
    INDEX `event`(`event`), 
    FOREIGN KEY (`event`)
    REFERENCES `flex_event`(`pk`),
    FOREIGN KEY (`row_`)
    REFERENCES `flex_row`(`pk`)
)ENGINE=INNODB
;



CREATE TABLE `iter_history`(
    `id`          BIGINT           AUTO_INCREMENT,
    `dt_hist_id`  BIGINT,
    `it_num`      BIGINT           NOT NULL,
    `td_row_num`  BIGINT           NOT NULL,
    `start_time`  BIGINT           NOT NULL,
    `end_time`    BIGINT,
    `duration`    BIGINT,
    `result`      DECIMAL(3, 0),
    PRIMARY KEY (`id`), 
    INDEX `iter_history_idx1`(`dt_hist_id`),
    FOREIGN KEY (`dt_hist_id`)
    REFERENCES `dt_history`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `logmeasurement_mrv`(
    `id`          BIGINT          AUTO_INCREMENT,
    `attr_id_1`   BIGINT,
    `attr_val_1`  VARCHAR(255),
    `attr_id_2`   BIGINT,
    `attr_val_2`  VARCHAR(255),
    `attr_id_3`   BIGINT,
    `attr_val_3`  VARCHAR(255),
    `attr_id_4`   BIGINT,
    `attr_val_4`  VARCHAR(255),
    `attr_id_5`   BIGINT,
    `attr_val_5`  VARCHAR(255),
    PRIMARY KEY (`id`), 
    INDEX `fk_logmeasurement_mrv1`(`attr_id_1`),
    INDEX `fk_logmeasurement_mrv2`(`attr_id_2`),
    INDEX `fk_logmeasurement_mrv3`(`attr_id_3`),
    INDEX `fk_logmeasurement_mrv4`(`attr_id_4`),
    INDEX `fk_logmeasurement_mrv5`(`attr_id_5`), 
    FOREIGN KEY (`attr_id_1`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`attr_id_2`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`attr_id_3`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`attr_id_4`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`attr_id_5`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `logmeasurement_ts`(
    `idx`                    BIGINT          AUTO_INCREMENT,
    `logmeasurement_mrv_id`  BIGINT          NOT NULL,
    `execution_id`           BIGINT,
    `time`                   BIGINT          NOT NULL,
    `ctr_id_1`               BIGINT,
    `ctr_val_1`              BIGINT,
    `ctr_id_2`               BIGINT,
    `ctr_val_2`              BIGINT,
    `ctr_id_3`               BIGINT,
    `ctr_val_3`              BIGINT,
    `ctr_id_4`               BIGINT,
    `ctr_val_4`              BIGINT,
    `ctr_id_5`               BIGINT,
    `ctr_val_5`              BIGINT,
    `ctr_id_6`               BIGINT,
    `ctr_val_6`              BIGINT,
    `ctr_id_7`               BIGINT,
    `ctr_val_7`              BIGINT,
    `ctr_id_8`               BIGINT,
    `ctr_val_8`              BIGINT,
    `strctr_id_1`            BIGINT,
    `strctr_val_1`           VARCHAR(255),
    `strctr_id_2`            BIGINT,
    `strctr_val_2`           VARCHAR(255),
    `strctr_id_3`            BIGINT,
    `strctr_val_3`           VARCHAR(255),
    `strctr_id_4`            BIGINT,
    `strctr_val_4`           VARCHAR(255),
    PRIMARY KEY (`idx`), 
    INDEX `logmeasurement_ts_index1`(`time`),
    INDEX `logmeasurement_ts_index2`(`execution_id`),
    INDEX `fk_logmeasurement_ts`(`logmeasurement_mrv_id`),
    INDEX `fk_logmeasurement_ts1`(`ctr_id_1`),
    INDEX `fk_logmeasurement_ts10`(`strctr_id_2`),
    INDEX `fk_logmeasurement_ts11`(`strctr_id_3`),
    INDEX `fk_logmeasurement_ts12`(`strctr_id_4`),
    INDEX `fk_logmeasurement_ts2`(`ctr_id_2`),
    INDEX `fk_logmeasurement_ts3`(`ctr_id_3`),
    INDEX `fk_logmeasurement_ts4`(`ctr_id_4`),
    INDEX `fk_logmeasurement_ts5`(`ctr_id_5`),
    INDEX `fk_logmeasurement_ts6`(`ctr_id_6`),
    INDEX `fk_logmeasurement_ts7`(`ctr_id_7`),
    INDEX `fk_logmeasurement_ts8`(`ctr_id_8`),
    INDEX `fk_logmeasurement_ts9`(`strctr_id_1`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`logmeasurement_mrv_id`)
    REFERENCES `logmeasurement_mrv`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ctr_id_1`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`strctr_id_2`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`strctr_id_3`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`strctr_id_4`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ctr_id_2`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ctr_id_3`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ctr_id_4`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ctr_id_5`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ctr_id_6`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ctr_id_7`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`ctr_id_8`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`strctr_id_1`)
    REFERENCES `counter_details`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `perform_charts`(
    `chart_name`    VARCHAR(100)    NOT NULL,
    `project_id`    BIGINT          NOT NULL,
    `execution_id`  BIGINT          NOT NULL,
    `data`          LONGTEXT        NOT NULL,
    `image1`        LONGBLOB,
    `image2`        LONGBLOB,
    PRIMARY KEY (`chart_name`, `project_id`), 
    INDEX `project_id`(`project_id`),
    INDEX `execution_id`(`execution_id`), 
    FOREIGN KEY (`project_id`)
    REFERENCES `project`(`id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `perform_execution`(
    `execution_id`     BIGINT    NOT NULL,
    `appmodelitem_id`  BIGINT    NOT NULL,
    `iterations`       BIGINT,
    `avg_iter_dur`     BIGINT,
    `max_iter_dur`     BIGINT,
    `transactions`     BIGINT,
    `avg_trans_dur`    BIGINT,
    `max_trans_dur`    BIGINT,
    PRIMARY KEY (`execution_id`), 
    INDEX `appmodelitem_id`(`appmodelitem_id`), 
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `probe_config`(
    `execution_id`  BIGINT      NOT NULL,
    `config`        LONGTEXT,
    PRIMARY KEY (`execution_id`), 
    CONSTRAINT `probe_config_ibfk_2` FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `rvhi_mrv`(
    `id`         BIGINT            AUTO_INCREMENT,
    `grp`        VARCHAR(30)       NOT NULL,
    `hostip`     VARCHAR(20)       NOT NULL,
    `hostname`   VARCHAR(50)       NOT NULL,
    `service`    VARCHAR(20)       NOT NULL,
    `time`       BIGINT            NOT NULL,
    `network`    VARCHAR(20)       NOT NULL,
    `sn`         BIGINT            NOT NULL,
    `os`         VARCHAR(20)       NOT NULL,
    `ver`        VARCHAR(10)       NOT NULL,
    `httpaddr`   VARCHAR(20)       NOT NULL,
    `httpport`   DECIMAL(10, 0)    NOT NULL,
    `up`         BIGINT            NOT NULL,
    `username`   VARCHAR(30)       NOT NULL,
    `processid`  BIGINT            NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `rvhi_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `rvhi_ts`(
    `idx`           BIGINT    NOT NULL,
    `rvhi_mrv_id`   BIGINT    NOT NULL,
    `execution_id`  BIGINT,
    `time`          BIGINT    NOT NULL,
    `ms`            BIGINT    NOT NULL,
    `mr`            BIGINT    NOT NULL,
    `ps`            BIGINT    NOT NULL,
    `pr`            BIGINT    NOT NULL,
    `bs`            BIGINT    NOT NULL,
    `br`            BIGINT    NOT NULL,
    `rx`            BIGINT    NOT NULL,
    `pm`            BIGINT    NOT NULL,
    INDEX `rvhi_ts_index1`(`time`),
    INDEX `rvhi_ts_index2`(`execution_id`),
    INDEX `sys_c004463`(`rvhi_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`rvhi_mrv_id`)
    REFERENCES `rvhi_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_network_mrv`(
    `id`         BIGINT         AUTO_INCREMENT,
    `networkid`  VARCHAR(20)    NOT NULL,
    `time`       BIGINT         NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `rvtrace_network_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_multicast_mrv`(
    `id`                      BIGINT         AUTO_INCREMENT,
    `rvtrace_network_mrv_id`  BIGINT         NOT NULL,
    `service`                 VARCHAR(20)    NOT NULL,
    `hostip`                  VARCHAR(20)    NOT NULL,
    `hostname`                VARCHAR(50)    NOT NULL,
    `destination`             VARCHAR(20)    NOT NULL,
    `time`                    BIGINT         NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `rvtrace_multicast_mrv_index1`(`time`),
    INDEX `sys_c004518`(`rvtrace_network_mrv_id`), 
    FOREIGN KEY (`rvtrace_network_mrv_id`)
    REFERENCES `rvtrace_network_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_multicast_ts`(
    `idx`                       BIGINT    NOT NULL,
    `rvtrace_multicast_mrv_id`  BIGINT    NOT NULL,
    `execution_id`              BIGINT,
    `time`                      BIGINT    NOT NULL,
    `packets`                   BIGINT    NOT NULL,
    `bytes`                     BIGINT    NOT NULL,
    `rtpackets`                 BIGINT    NOT NULL,
    `rtbytes`                   BIGINT    NOT NULL,
    `nullpackets`               BIGINT    NOT NULL,
    `missedpackets`             BIGINT    NOT NULL,
    `badpackets`                BIGINT    NOT NULL,
    INDEX `rvtrace_multicast_ts_index1`(`time`),
    INDEX `rvtrace_multicast_ts_index2`(`execution_id`),
    INDEX `sys_c004530`(`rvtrace_multicast_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`rvtrace_multicast_mrv_id`)
    REFERENCES `rvtrace_multicast_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_network_ts`(
    `idx`                     BIGINT    NOT NULL,
    `rvtrace_network_mrv_id`  BIGINT    NOT NULL,
    `execution_id`            BIGINT,
    `time`                    BIGINT    NOT NULL,
    `packets`                 BIGINT    NOT NULL,
    `bytes`                   BIGINT    NOT NULL,
    INDEX `rvtrace_network_ts_index1`(`time`),
    INDEX `rvtrace_network_ts_index2`(`execution_id`),
    INDEX `sys_c004509`(`rvtrace_network_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`rvtrace_network_mrv_id`)
    REFERENCES `rvtrace_network_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_ptp_mrv`(
    `id`                      BIGINT         AUTO_INCREMENT,
    `rvtrace_network_mrv_id`  BIGINT         NOT NULL,
    `service`                 VARCHAR(20)    NOT NULL,
    `hostip`                  VARCHAR(20)    NOT NULL,
    `hostname`                VARCHAR(50)    NOT NULL,
    `time`                    BIGINT         NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `rvtrace_ptp_mrv_index1`(`time`),
    INDEX `sys_c004559`(`rvtrace_network_mrv_id`), 
    FOREIGN KEY (`rvtrace_network_mrv_id`)
    REFERENCES `rvtrace_network_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_ptp_ts`(
    `idx`                 BIGINT    NOT NULL,
    `rvtrace_ptp_mrv_id`  BIGINT    NOT NULL,
    `execution_id`        BIGINT,
    `time`                BIGINT    NOT NULL,
    `pckssent`            BIGINT    NOT NULL,
    `bytessent`           BIGINT    NOT NULL,
    `ackreqsent`          BIGINT    NOT NULL,
    `ackssent`            BIGINT    NOT NULL,
    `nackssent`           BIGINT    NOT NULL,
    `badpckssent`         BIGINT    NOT NULL,
    `pcksrcvd`            BIGINT    NOT NULL,
    `bytesrcvd`           BIGINT    NOT NULL,
    `ackreqrcvd`          BIGINT    NOT NULL,
    `acksrcvd`            BIGINT    NOT NULL,
    `nacksrcvd`           BIGINT    NOT NULL,
    `badpcksrcvd`         BIGINT    NOT NULL,
    INDEX `rvtrace_ptp_ts_index1`(`time`),
    INDEX `rvtrace_ptp_ts_index2`(`execution_id`),
    INDEX `sys_c004576`(`rvtrace_ptp_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`rvtrace_ptp_mrv_id`)
    REFERENCES `rvtrace_ptp_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_retrans_mrv`(
    `id`                      BIGINT         AUTO_INCREMENT,
    `rvtrace_network_mrv_id`  BIGINT         NOT NULL,
    `service`                 VARCHAR(20)    NOT NULL,
    `hostip`                  VARCHAR(20)    NOT NULL,
    `hostname`                VARCHAR(50)    NOT NULL,
    `time`                    BIGINT         NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `rvtrace_retrans_mrv_index1`(`time`),
    INDEX `sys_c004538`(`rvtrace_network_mrv_id`), 
    FOREIGN KEY (`rvtrace_network_mrv_id`)
    REFERENCES `rvtrace_network_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_retrans_ts`(
    `idx`                     BIGINT    NOT NULL,
    `rvtrace_retrans_mrv_id`  BIGINT    NOT NULL,
    `execution_id`            BIGINT,
    `time`                    BIGINT    NOT NULL,
    `pckssent`                BIGINT    NOT NULL,
    `seqreq`                  BIGINT    NOT NULL,
    `rejsent`                 BIGINT    NOT NULL,
    `badsent`                 BIGINT    NOT NULL,
    `pcksrcvd`                BIGINT    NOT NULL,
    `seqreqfrom`              BIGINT    NOT NULL,
    `rejrcvd`                 BIGINT    NOT NULL,
    `badrcvd`                 BIGINT    NOT NULL,
    INDEX `rvtrace_retrans_ts_index1`(`time`),
    INDEX `rvtrace_retrans_ts_index2`(`execution_id`),
    INDEX `sys_c004551`(`rvtrace_retrans_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`rvtrace_retrans_mrv_id`)
    REFERENCES `rvtrace_retrans_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_subject_mrv`(
    `id`                      BIGINT          AUTO_INCREMENT,
    `rvtrace_network_mrv_id`  BIGINT          NOT NULL,
    `service`                 VARCHAR(20)     NOT NULL,
    `subject`                 VARCHAR(150)    NOT NULL,
    `time`                    BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `rvtrace_subject_mrv_index1`(`time`),
    INDEX `sys_c004583`(`rvtrace_network_mrv_id`), 
    FOREIGN KEY (`rvtrace_network_mrv_id`)
    REFERENCES `rvtrace_network_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `rvtrace_subject_ts`(
    `idx`                     BIGINT    NOT NULL,
    `rvtrace_subject_mrv_id`  BIGINT    NOT NULL,
    `execution_id`            BIGINT,
    `time`                    BIGINT    NOT NULL,
    `messages`                BIGINT    NOT NULL,
    `bytes`                   BIGINT    NOT NULL,
    INDEX `rvtrace_subject_ts_index1`(`time`),
    INDEX `rvtrace_subject_ts_index2`(`execution_id`),
    INDEX `sys_c004590`(`rvtrace_subject_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`rvtrace_subject_mrv_id`)
    REFERENCES `rvtrace_subject_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `scenario`(
    `id`       BIGINT         AUTO_INCREMENT,
    `display`  VARCHAR(64),
    `uniqueid` VARCHAR(32),
    `appmodelitem_id` BIGINT,
    PRIMARY KEY (`id`),
    UNIQUE INDEX `appmodelitem_id`(`appmodelitem_id`, `uniqueid`, `display` ),
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `scenario_execution`(
    `execution_id`  BIGINT    NOT NULL,
    `scenario_id`   BIGINT    NOT NULL,
    PRIMARY KEY (`execution_id`), 
    INDEX `ref80117`(`execution_id`),
    INDEX `ref81118`(`scenario_id`), 
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`scenario_id`)
    REFERENCES `scenario`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sonic_agent_mrv`(
    `id`         BIGINT          AUTO_INCREMENT,
    `domain`     VARCHAR(256)    NOT NULL,
    `container`  VARCHAR(256)    NOT NULL,
    `time`       BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `sonic_agent_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `sonic_agent_ts`(
    `idx`                 BIGINT    NOT NULL,
    `sonic_agent_mrv_id`  BIGINT    NOT NULL,
    `execution_id`        BIGINT,
    `time`                BIGINT    NOT NULL,
    `poolwaits`           BIGINT,
    `maxpoolsize`         BIGINT,
    `poolsize`            BIGINT,
    `totalthreads`        BIGINT,
    `maxmemusage`         BIGINT,
    `memusage`            BIGINT,
    INDEX `sonic_agent_ts_index1`(`time`),
    INDEX `sonic_agent_ts_index2`(`execution_id`),
    INDEX `sys_c004600`(`sonic_agent_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`sonic_agent_mrv_id`)
    REFERENCES `sonic_agent_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sonic_broker_mrv`(
    `id`                  BIGINT          AUTO_INCREMENT,
    `sonic_agent_mrv_id`  BIGINT          NOT NULL,
    `broker`              VARCHAR(255)    NOT NULL,
    `time`                BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `sonic_broker_mrv_index1`(`sonic_agent_mrv_id`, `broker`), 
    FOREIGN KEY (`sonic_agent_mrv_id`)
    REFERENCES `sonic_agent_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sonic_broker_ts`(
    `idx`                  BIGINT    NOT NULL,
    `sonic_broker_mrv_id`  BIGINT    NOT NULL,
    `execution_id`         BIGINT,
    `time`                 BIGINT    NOT NULL,
    `appmsgreceived`       BIGINT,
    `appmsgdelivered`      BIGINT,
    `bytesreceived`        BIGINT,
    `bytesdelivered`       BIGINT,
    `connscount`           BIGINT,
    `connsreject`          BIGINT,
    `topicstoresize`       BIGINT,
    INDEX `sonic_broker_ts_index1`(`time`),
    INDEX `sonic_broker_ts_index2`(`execution_id`),
    INDEX `sys_c004611`(`sonic_broker_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`sonic_broker_mrv_id`)
    REFERENCES `sonic_broker_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sonic_conns_mrv`(
    `id`                  BIGINT          AUTO_INCREMENT,
    `sonic_agent_mrv_id`  BIGINT          NOT NULL,
    `broker`              VARCHAR(256)    NOT NULL,
    `conn`                VARCHAR(256)    NOT NULL,
    `time`                BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `sonic_conns_mrv_index1`(`time`),
    INDEX `sys_c004630`(`sonic_agent_mrv_id`), 
    FOREIGN KEY (`sonic_agent_mrv_id`)
    REFERENCES `sonic_agent_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sonic_conns_ts`(
    `idx`                 BIGINT    NOT NULL,
    `sonic_conns_mrv_id`  BIGINT    NOT NULL,
    `execution_id`        BIGINT,
    `time`                BIGINT    NOT NULL,
    `msgreceived`         BIGINT,
    `msgdelivered`        BIGINT,
    INDEX `sonic_conns_ts_index1`(`time`),
    INDEX `sonic_conns_ts_index2`(`execution_id`),
    INDEX `sys_c004635`(`sonic_conns_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`sonic_conns_mrv_id`)
    REFERENCES `sonic_conns_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sonic_queue_mrv`(
    `id`                  BIGINT          AUTO_INCREMENT,
    `sonic_agent_mrv_id`  BIGINT          NOT NULL,
    `broker`              VARCHAR(256)    NOT NULL,
    `queue`               VARCHAR(256)    NOT NULL,
    `time`                BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `sonic_queue_mrv_index1`(`time`),
    INDEX `sys_c004618`(`sonic_agent_mrv_id`), 
    FOREIGN KEY (`sonic_agent_mrv_id`)
    REFERENCES `sonic_agent_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sonic_queue_ts`(
    `idx`                 BIGINT    NOT NULL,
    `sonic_queue_mrv_id`  BIGINT    NOT NULL,
    `execution_id`        BIGINT,
    `time`                BIGINT    NOT NULL,
    `msgdelivered`        BIGINT,
    `msgreceived`         BIGINT,
    `maxdepth`            BIGINT,
    `msgcount`            BIGINT,
    `msgsize`             BIGINT,
    INDEX `sonic_queue_ts_index1`(`time`),
    INDEX `sonic_queue_ts_index2`(`execution_id`),
    INDEX `sys_c004623`(`sonic_queue_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`sonic_queue_mrv_id`)
    REFERENCES `sonic_queue_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `suite_execution`(
    `execution_id`         BIGINT    NOT NULL,
    `appmodelitem_id`      BIGINT    NOT NULL,
    `action_execution_id`  BIGINT,
    `expiration`    BIGINT,
    PRIMARY KEY (`execution_id`), 
    INDEX `ref7782`(`appmodelitem_id`),
    INDEX `action_execution_id`(`action_execution_id`), 
    INDEX `suite_exec_exp_idx`(`expiration`), 
    FOREIGN KEY (`action_execution_id`)
    REFERENCES `action_execution`(`id`),
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `sysstat_sys_stats_mrv`(
    `id`                 BIGINT          AUTO_INCREMENT,
    `hostname`           VARCHAR(256)    NOT NULL,
    `time`               BIGINT          NOT NULL,
    `avg_cpu_load`       FLOAT(0)        NOT NULL,
    `cpu_load_1`         FLOAT(0),
    `cpu_load_2`         FLOAT(0),
    `cpu_load_3`         FLOAT(0),
    `cpu_load_4`         FLOAT(0),
    `cpu_load_5`         FLOAT(0),
    `cpu_load_6`         FLOAT(0),
    `cpu_load_7`         FLOAT(0),
    `cpu_load_8`         FLOAT(0),
    `used_ram`           FLOAT(0)        NOT NULL,
    `disk_busy`          FLOAT(0)        NOT NULL,
    `network_usage`      FLOAT(0)        NOT NULL,
    `network_errors`     FLOAT(0)        NOT NULL,
    `waiting_threads`    FLOAT(0)        NOT NULL,
    `memory_saturation`  FLOAT(0)        NOT NULL,
    `waiting_disk_ops`   FLOAT(0)        NOT NULL,
    `used_swap`          FLOAT(0)        NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `sysstat_sys_stats_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `sysstat_proc_stats_mrv`(
    `id`                        BIGINT          AUTO_INCREMENT,
    `sysstat_sys_stats_mrv_id`  BIGINT          NOT NULL,
    `process_name`              VARCHAR(256)    NOT NULL,
    `process_id`                VARCHAR(256)    NOT NULL,
    `time`                      BIGINT          NOT NULL,
    `process_cpu`               FLOAT(0),
    `process_mem`               FLOAT(0),
    PRIMARY KEY (`id`), 
    INDEX `sysstat_proc_stats_mrv_index1`(`time`),
    INDEX `sys_c004669`(`sysstat_sys_stats_mrv_id`), 
    FOREIGN KEY (`sysstat_sys_stats_mrv_id`)
    REFERENCES `sysstat_sys_stats_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sysstat_proc_stats_ts`(
    `idx`                        BIGINT      NOT NULL,
    `sysstat_proc_stats_mrv_id`  BIGINT      NOT NULL,
    `execution_id`               BIGINT,
    `time`                       BIGINT      NOT NULL,
    `process_cpu`                FLOAT(0),
    `process_mem`                FLOAT(0),
    INDEX `sysstat_proc_stats_ts_index1`(`time`),
    INDEX `sysstat_proc_stats_ts_index2`(`execution_id`),
    INDEX `sys_c004674`(`sysstat_proc_stats_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`sysstat_proc_stats_mrv_id`)
    REFERENCES `sysstat_proc_stats_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `sysstat_sys_stats_ts`(
    `idx`                       BIGINT      NOT NULL,
    `sysstat_sys_stats_mrv_id`  BIGINT      NOT NULL,
    `execution_id`              BIGINT,
    `time`                      BIGINT      NOT NULL,
    `avg_cpu_load`              FLOAT(0)    NOT NULL,
    `cpu_load_1`                FLOAT(0),
    `cpu_load_2`                FLOAT(0),
    `cpu_load_3`                FLOAT(0),
    `cpu_load_4`                FLOAT(0),
    `cpu_load_5`                FLOAT(0),
    `cpu_load_6`                FLOAT(0),
    `cpu_load_7`                FLOAT(0),
    `cpu_load_8`                FLOAT(0),
    `used_ram`                  FLOAT(0)    NOT NULL,
    `disk_busy`                 FLOAT(0)    NOT NULL,
    `network_usage`             FLOAT(0)    NOT NULL,
    `network_errors`            FLOAT(0)    NOT NULL,
    `waiting_threads`           FLOAT(0)    NOT NULL,
    `memory_saturation`         FLOAT(0)    NOT NULL,
    `waiting_disk_ops`          FLOAT(0)    NOT NULL,
    `used_swap`                 FLOAT(0)    NOT NULL,
    INDEX `sysstat_sys_stats_ts_index1`(`time`),
    INDEX `sysstat_sys_stats_ts_index2`(`execution_id`),
    INDEX `sys_c004662`(`sysstat_sys_stats_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`sysstat_sys_stats_mrv_id`)
    REFERENCES `sysstat_sys_stats_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `test_cycle`(
    `id`            BIGINT         AUTO_INCREMENT,
    `execution_id`  BIGINT         NOT NULL,
    `display`       VARCHAR(255)   NOT NULL,
    `comments`      VARCHAR(4000),
    `is_closed`     CHAR(1)        NOT NULL,
    `created_by`    VARCHAR(255)   NOT NULL,
    `create_date`   BIGINT         NOT NULL,
    `closed_by`     VARCHAR(255),
    `closed_date`   BIGINT,
    PRIMARY KEY (`id`),
    UNIQUE INDEX `test_cycle_unique`(`display`),
    FOREIGN KEY (`execution_id`) 
    REFERENCES `execution`(`id`)
)
;



CREATE TABLE `test_cycle_project`(
    `id`                     BIGINT  AUTO_INCREMENT,
    `test_cycle_id`          BIGINT  NOT NULL,
    `project_id`             BIGINT  NOT NULL,
    `joined_date`            BIGINT  NOT NULL,
    `all_environments`       CHAR(1) NOT NULL,
    `allow_external_tools`   CHAR(1) NOT NULL,
    `is_joined`              CHAR(1) NOT NULL,
    PRIMARY KEY (`id`),
    UNIQUE INDEX `trp_unique`(test_cycle_id, project_id),
    FOREIGN KEY (`test_cycle_id`)
    REFERENCES `test_cycle`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`project_id`)
    REFERENCES `PROJECT`(`id`)
)
;



CREATE TABLE `test_cycle_project_env`(
    `test_cycle_project_id`    BIGINT       NOT NULL,
    `environment`              VARCHAR(255) NOT NULL,
    PRIMARY KEY (`test_cycle_project_id`, `environment` ),
    FOREIGN KEY (`test_cycle_project_id`)
    REFERENCES `test_cycle_project`(`id`) ON DELETE CASCADE
)
;



CREATE TABLE `test_cycle_project_user`(
    `test_cycle_project_id` BIGINT       NOT NULL,
    `username`              VARCHAR(255) NOT NULL,
    `joined_date`           BIGINT       NOT NULL,
    PRIMARY KEY (`TEST_CYCLE_PROJECT_ID`, `USERNAME` ),
    FOREIGN KEY (`test_cycle_project_id`)
    REFERENCES `test_cycle_project`(`id`) ON DELETE CASCADE
)
;



CREATE TABLE `testengine_engine_mrv`(
    `id`    BIGINT          AUTO_INCREMENT,
    `url`   VARCHAR(255)    NOT NULL,
    `time`  BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `testengine_engine_mrv_uni`(`url`),
    INDEX `testengine_engine_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `testengine_engine_ts`(
    `idx`                       BIGINT      NOT NULL,
    `testengine_engine_mrv_id`  BIGINT      NOT NULL,
    `execution_id`              BIGINT,
    `time`                      BIGINT      NOT NULL,
    `db_writes`                 BIGINT      NOT NULL,
    `thread_pool_usage`         FLOAT(0)    NOT NULL,
    `threads_used`              BIGINT      NOT NULL,
    `memory_usage`              FLOAT(0)    NOT NULL,
    `memory_used`               BIGINT      NOT NULL,
    INDEX `testengine_engine_ts_index1`(`time`),
    INDEX `testengine_engine_ts_index2`(`execution_id`),
    INDEX `fk_testengine_engine_ts`(`testengine_engine_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`testengine_engine_mrv_id`)
    REFERENCES `testengine_engine_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `testengine_seq_mrv`(
    `id`                        BIGINT          AUTO_INCREMENT,
    `testengine_engine_mrv_id`  BIGINT          NOT NULL,
    `seq_name`                  VARCHAR(255)    NOT NULL,
    `time`                      BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `testengine_seq_mrv_uni`(`testengine_engine_mrv_id`, `seq_name`),
    INDEX `testengine_seq_mrv_index1`(`time`),
    INDEX `fk_testengine_seq_mrv`(`testengine_engine_mrv_id`), 
    FOREIGN KEY (`testengine_engine_mrv_id`)
    REFERENCES `testengine_engine_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `testengine_seq_ts`(
    `idx`                    BIGINT      NOT NULL,
    `testengine_seq_mrv_id`  BIGINT      NOT NULL,
    `execution_id`           BIGINT,
    `time`                   BIGINT      NOT NULL,
    `avg_duration`           FLOAT(0)    NOT NULL,
    `max_duration`           BIGINT      NOT NULL,
    `min_duration`           BIGINT      NOT NULL,
    `avg_duration_fail`      FLOAT(0)    NOT NULL,
    `max_duration_fail`      BIGINT      NOT NULL,
    `min_duration_fail`      BIGINT      NOT NULL,
    `rate_started`           FLOAT(0)    NOT NULL,
    `rate_completed`         FLOAT(0)    NOT NULL,
    INDEX `testengine_seq_ts_index1`(`time`),
    INDEX `testengine_seq_ts_index2`(`execution_id`),
    INDEX `fk_testengine_seq_ts`(`testengine_seq_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`testengine_seq_mrv_id`)
    REFERENCES `testengine_seq_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `testengine_trans_mrv`(
    `id`                        BIGINT          AUTO_INCREMENT,
    `testengine_engine_mrv_id`  BIGINT          NOT NULL,
    `trans_name`                VARCHAR(255)    NOT NULL,
    `time`                      BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `testengine_trans_mrv_uni`(`testengine_engine_mrv_id`, `trans_name`),
    INDEX `testengine_trans_mrv_index1`(`time`),
    INDEX `fk_testengine_trans_mrv`(`testengine_engine_mrv_id`), 
    FOREIGN KEY (`testengine_engine_mrv_id`)
    REFERENCES `testengine_engine_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `testengine_trans_ts`(
    `idx`                      BIGINT      NOT NULL,
    `testengine_trans_mrv_id`  BIGINT      NOT NULL,
    `execution_id`             BIGINT,
    `time`                     BIGINT      NOT NULL,
    `avg_duration`             FLOAT(0)    NOT NULL,
    `max_duration`             BIGINT      NOT NULL,
    `min_duration`             BIGINT      NOT NULL,
    `avg_duration_fail`        FLOAT(0)    NOT NULL,
    `max_duration_fail`        BIGINT      NOT NULL,
    `min_duration_fail`        BIGINT      NOT NULL,
    `rate_started`             FLOAT(0)    NOT NULL,
    `rate_passed`              FLOAT(0)    NOT NULL,
    `rate_failed`              FLOAT(0)    NOT NULL,
    `rate_timeout`             FLOAT(0)    NOT NULL,
    INDEX `testengine_trans_ts_index1`(`time`),
    INDEX `testengine_trans_ts_index2`(`execution_id`),
    INDEX `pk_testengine_trans_ts`(`testengine_trans_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`testengine_trans_mrv_id`)
    REFERENCES `testengine_trans_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `tester_seq_end_mrv`(
    `id`               BIGINT          AUTO_INCREMENT,
    `appmodelitem_id`  BIGINT          NOT NULL,
    `seq_name`         VARCHAR(255)    NOT NULL,
    `time`             BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `fk_tester_seq_end_mrv`(`appmodelitem_id`), 
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `tester_seq_end_ts`(
    `idx`                    BIGINT      NOT NULL,
    `tester_seq_end_mrv_id`  BIGINT      NOT NULL,
    `execution_id`           BIGINT,
    `time`                   BIGINT      NOT NULL,
    `avg_duration`           FLOAT(0)    DEFAULT 0 NOT NULL,
    `max_duration`           BIGINT      DEFAULT 0 NOT NULL,
    `min_duration`           BIGINT      DEFAULT 0 NOT NULL,
    `avg_duration_fail`      FLOAT(0)    DEFAULT 0 NOT NULL,
    `max_duration_fail`      BIGINT      DEFAULT 0 NOT NULL,
    `min_duration_fail`      BIGINT      DEFAULT 0 NOT NULL,
    `rate_ended`             FLOAT(0)    NOT NULL,
    `rate_passed`            FLOAT(0)    NOT NULL,
    `rate_failed`            FLOAT(0)    NOT NULL,
    `rate_timeout`           FLOAT(0)    NOT NULL,
    INDEX `tester_seq_end_ts_index1`(`time`),
    INDEX `tester_seq_end_ts_index2`(`execution_id`),
    INDEX `fk_tester_seq_end_ts`(`tester_seq_end_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`tester_seq_end_mrv_id`)
    REFERENCES `tester_seq_end_mrv`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `tester_seq_mrv`(
    `id`               BIGINT          AUTO_INCREMENT,
    `appmodelitem_id`  BIGINT          NOT NULL,
    `seq_name`         VARCHAR(255)    NOT NULL,
    `time`             BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `fk_tester_seq_mrv`(`appmodelitem_id`), 
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `tester_seq_ts`(
    `idx`                BIGINT      NOT NULL,
    `tester_seq_mrv_id`  BIGINT      NOT NULL,
    `execution_id`       BIGINT,
    `time`               BIGINT      NOT NULL,
    `avg_duration`       FLOAT(0)    DEFAULT 0 NOT NULL,
    `max_duration`       BIGINT      DEFAULT 0 NOT NULL,
    `min_duration`       BIGINT      DEFAULT 0 NOT NULL,
    `avg_duration_fail`  FLOAT(0)    DEFAULT 0 NOT NULL,
    `max_duration_fail`  BIGINT      DEFAULT 0 NOT NULL,
    `min_duration_fail`  BIGINT      DEFAULT 0 NOT NULL,
    `rate_started`       FLOAT(0)    NOT NULL,
    `rate_passed`        FLOAT(0)    NOT NULL,
    `rate_failed`        FLOAT(0)    NOT NULL,
    `rate_timeout`       FLOAT(0)    NOT NULL,
    INDEX `tester_seq_ts_index1`(`time`),
    INDEX `tester_seq_ts_index2`(`execution_id`),
    INDEX `fk_tester_seq_ts`(`tester_seq_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`tester_seq_mrv_id`)
    REFERENCES `tester_seq_mrv`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `tester_trans_end_mrv`(
    `id`               BIGINT            AUTO_INCREMENT,
    `appmodelitem_id`  BIGINT            NOT NULL,
    `trans_name`       VARCHAR(255)      NOT NULL,
    `time`             DECIMAL(20, 0)    NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `fk_tester_trans_end_mrv`(`appmodelitem_id`), 
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `tester_trans_end_ts`(
    `idx`                      BIGINT      NOT NULL,
    `tester_trans_end_mrv_id`  BIGINT      NOT NULL,
    `execution_id`             BIGINT,
    `time`                     BIGINT      NOT NULL,
    `avg_duration`             FLOAT(0)    DEFAULT 0 NOT NULL,
    `max_duration`             BIGINT      DEFAULT 0 NOT NULL,
    `min_duration`             BIGINT      DEFAULT 0 NOT NULL,
    `avg_duration_fail`        FLOAT(0)    DEFAULT 0 NOT NULL,
    `max_duration_fail`        BIGINT      DEFAULT 0 NOT NULL,
    `min_duration_fail`        BIGINT      DEFAULT 0 NOT NULL,
    `rate_ended`               FLOAT(0)    NOT NULL,
    `rate_passed`              FLOAT(0)    NOT NULL,
    `rate_failed`              FLOAT(0)    NOT NULL,
    `rate_timeout`             FLOAT(0)    NOT NULL,
    INDEX `tester_trans_end_ts_index1`(`time`),
    INDEX `tester_trans_end_ts_index2`(`execution_id`),
    INDEX `fk_teser_trans_end_ts`(`tester_trans_end_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`tester_trans_end_mrv_id`)
    REFERENCES `tester_trans_end_mrv`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `tester_trans_mrv`(
    `id`               BIGINT          AUTO_INCREMENT,
    `appmodelitem_id`  BIGINT          NOT NULL,
    `trans_name`       VARCHAR(255)    NOT NULL,
    `time`             BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `fk_tester_trans_mrv`(`appmodelitem_id`), 
    FOREIGN KEY (`appmodelitem_id`)
    REFERENCES `appmodelitem`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `tester_trans_ts`(
    `idx`                  BIGINT      NOT NULL,
    `tester_trans_mrv_id`  BIGINT      NOT NULL,
    `execution_id`         BIGINT,
    `time`                 BIGINT      NOT NULL,
    `avg_duration`         FLOAT(0)    DEFAULT 0 NOT NULL,
    `max_duration`         BIGINT      DEFAULT 0 NOT NULL,
    `min_duration`         BIGINT      DEFAULT 0 NOT NULL,
    `avg_duration_fail`    FLOAT(0)    DEFAULT 0 NOT NULL,
    `max_duration_fail`    BIGINT      DEFAULT 0 NOT NULL,
    `min_duration_fail`    BIGINT      DEFAULT 0 NOT NULL,
    `rate_started`         FLOAT(0)    NOT NULL,
    `rate_passed`          FLOAT(0)    NOT NULL,
    `rate_failed`          FLOAT(0)    NOT NULL,
    `rate_timeout`         FLOAT(0)    NOT NULL,
    INDEX `tester_trans_ts_index1`(`time`),
    INDEX `tester_trans_ts_index2`(`execution_id`),
    INDEX `fk_tester_trans_ts`(`tester_trans_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`tester_trans_mrv_id`)
    REFERENCES `tester_trans_mrv`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `transaction`(
    `id`    BIGINT          AUTO_INCREMENT,
    `name`  VARCHAR(255)    NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `transaction_uni`(`name`)
)ENGINE=INNODB
;



CREATE TABLE `trans_history`(
    `id`            BIGINT    AUTO_INCREMENT,
    `iter_hist_id`  BIGINT,
    `trans_id`      BIGINT    NOT NULL,
    `start_time`    BIGINT    NOT NULL,
    `end_time`      BIGINT,
    `duration`      BIGINT,
    `result`        BIGINT,
    PRIMARY KEY (`id`), 
    INDEX `trans_history_index1`(`iter_hist_id`),
    INDEX `trans_id`(`trans_id`), 
    FOREIGN KEY (`trans_id`)
    REFERENCES `transaction`(`id`),
    FOREIGN KEY (`iter_hist_id`)
    REFERENCES `iter_history`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `wmbroker_b_mrv`(
    `id`                         BIGINT          AUTO_INCREMENT,
    `host`                       VARCHAR(255)    NOT NULL,
    `port`                       BIGINT          NOT NULL,
    `broker`                     VARCHAR(255)    NOT NULL,
    `time`                       BIGINT          NOT NULL,
    `clients`                    BIGINT,
    `event_types`                BIGINT,
    `event_log_length`           BIGINT,
    `num_published`              BIGINT,
    `num_delivered`              BIGINT,
    `num_trace_published`        BIGINT,
    `num_queued`                 BIGINT,
    `num_trace_sessions`         BIGINT,
    `max_publishes`              BIGINT,
    `max_events`                 BIGINT,
    `next_sequence`              BIGINT,
    `retry_attempts`             BIGINT,
    `reserved_publishes`         BIGINT,
    `guaranteed_publishes`       BIGINT,
    `volatile_publishes`         BIGINT,
    `guaranteed_events`          BIGINT,
    `volatile_events`            BIGINT,
    `current_publishes`          BIGINT,
    `current_events`             BIGINT,
    `num_events_queued`          BIGINT,
    `last_enqueue_time`          BIGINT,
    `queue_length`               BIGINT,
    `queue_size`                 BIGINT,
    `queue_highest_length`       BIGINT,
    `queue_highest_length_time`  BIGINT,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `wmbroker_b_mrv_uni`(`host`, `port`, `broker`),
    INDEX `wmbroker_b_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `wmbroker_b_ts`(
    `idx`                        BIGINT    NOT NULL,
    `wmbroker_b_mrv_id`          BIGINT    NOT NULL,
    `execution_id`               BIGINT,
    `time`                       BIGINT    NOT NULL,
    `clients`                    BIGINT,
    `event_types`                BIGINT,
    `event_log_length`           BIGINT,
    `num_published`              BIGINT,
    `num_delivered`              BIGINT,
    `num_trace_published`        BIGINT,
    `num_queued`                 BIGINT,
    `num_trace_sessions`         BIGINT,
    `max_publishes`              BIGINT,
    `max_events`                 BIGINT,
    `next_sequence`              BIGINT,
    `retry_attempts`             BIGINT,
    `reserved_publishes`         BIGINT,
    `guaranteed_publishes`       BIGINT,
    `volatile_publishes`         BIGINT,
    `guaranteed_events`          BIGINT,
    `volatile_events`            BIGINT,
    `current_publishes`          BIGINT,
    `current_events`             BIGINT,
    `num_events_queued`          BIGINT,
    `last_enqueue_time`          BIGINT,
    `queue_length`               BIGINT,
    `queue_size`                 BIGINT,
    `queue_highest_length`       BIGINT,
    `queue_highest_length_time`  BIGINT,
    INDEX `wmbroker_b_ts_index1`(`time`),
    INDEX `wmbroker_b_ts_index2`(`execution_id`),
    INDEX `ref91131`(`wmbroker_b_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`wmbroker_b_mrv_id`)
    REFERENCES `wmbroker_b_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `wmbroker_c_mrv`(
    `id`                      BIGINT          AUTO_INCREMENT,
    `wmbroker_b_mrv_id`       BIGINT          NOT NULL,
    `client`                  VARCHAR(255)    NOT NULL,
    `time`                    BIGINT          NOT NULL,
    `num_published`           BIGINT,
    `num_delivered`           BIGINT,
    `num_queued`              BIGINT,
    `num_retrieved`           BIGINT,
    `num_unacked`             BIGINT,
    `last_published`          BIGINT,
    `last_delivered`          BIGINT,
    `last_queued`             BIGINT,
    `last_retrieved`          BIGINT,
    `queue_length`            BIGINT,
    `queue_size`              BIGINT,
    `high_queue_length`       BIGINT,
    `high_queue_length_time`  BIGINT,
    PRIMARY KEY (`id`), 
    INDEX `wmbroker_c_mrv_uni`(`wmbroker_b_mrv_id`, `client`),
    INDEX `wmbroker_c_mrv_index1`(`time`),
    INDEX `ref91133`(`wmbroker_b_mrv_id`), 
    FOREIGN KEY (`wmbroker_b_mrv_id`)
    REFERENCES `wmbroker_b_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `wmbroker_c_ts`(
    `idx`                     BIGINT    NOT NULL,
    `wmbroker_c_mrv_id`       BIGINT    NOT NULL,
    `execution_id`            BIGINT,
    `time`                    BIGINT    NOT NULL,
    `num_published`           BIGINT,
    `num_delivered`           BIGINT,
    `num_queued`              BIGINT,
    `num_retrieved`           BIGINT,
    `num_unacked`             BIGINT,
    `last_published`          BIGINT,
    `last_delivered`          BIGINT,
    `last_queued`             BIGINT,
    `last_retrieved`          BIGINT,
    `queue_length`            BIGINT,
    `queue_size`              BIGINT,
    `high_queue_length`       BIGINT,
    `high_queue_length_time`  BIGINT,
    INDEX `wmbroker_c_ts_index1`(`time`),
    INDEX `wmbroker_c_ts_index2`(`execution_id`),
    INDEX `ref93134`(`wmbroker_c_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`wmbroker_c_mrv_id`)
    REFERENCES `wmbroker_c_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `wmbroker_cg_mrv`(
    `id`                 BIGINT          AUTO_INCREMENT,
    `wmbroker_b_mrv_id`  BIGINT          NOT NULL,
    `client_group`       VARCHAR(255)    NOT NULL,
    `time`               BIGINT          NOT NULL,
    `num_published`      BIGINT,
    `num_delivered`      BIGINT,
    `last_published`     BIGINT,
    `last_delivered`     BIGINT,
    PRIMARY KEY (`id`), 
    INDEX `wmbroker_cg_mrv_index1`(`time`),
    UNIQUE INDEX `wmbroker_cg_mrv_uni`(`wmbroker_b_mrv_id`, `client_group`),
    INDEX `ref91136`(`wmbroker_b_mrv_id`), 
    FOREIGN KEY (`wmbroker_b_mrv_id`)
    REFERENCES `wmbroker_b_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `wmbroker_cg_ts`(
    `idx`                 BIGINT    NOT NULL,
    `wmbroker_cg_mrv_id`  BIGINT    NOT NULL,
    `execution_id`        BIGINT,
    `time`                BIGINT    NOT NULL,
    `num_published`       BIGINT,
    `num_delivered`       BIGINT,
    `last_published`      BIGINT,
    `last_delivered`      BIGINT,
    INDEX `wmbroker_cg_ts_index1`(`time`),
    INDEX `wmbroker_cg_ts_index2`(`execution_id`),
    INDEX `ref95137`(`wmbroker_cg_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`wmbroker_cg_mrv_id`)
    REFERENCES `wmbroker_cg_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `wmbroker_et_mrv`(
    `id`                 BIGINT          AUTO_INCREMENT,
    `wmbroker_b_mrv_id`  BIGINT          NOT NULL,
    `event_type`         VARCHAR(255)    NOT NULL,
    `time`               BIGINT          NOT NULL,
    `num_published`      BIGINT,
    `num_delivered`      BIGINT,
    `last_published`     BIGINT,
    `last_delivered`     BIGINT,
    `num_subscriptions`  BIGINT,
    `num_forwards`       BIGINT,
    `last_forward`       BIGINT,
    `publish_groups`     BIGINT,
    `subscribe_groups`   BIGINT,
    PRIMARY KEY (`id`), 
    INDEX `wmbroker_et_mrv_index1`(`time`),
    UNIQUE INDEX `wmbroker_et_mrv_uni`(`wmbroker_b_mrv_id`, `event_type`),
    INDEX `ref91139`(`wmbroker_b_mrv_id`), 
    FOREIGN KEY (`wmbroker_b_mrv_id`)
    REFERENCES `wmbroker_b_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `wmbroker_et_ts`(
    `idx`                 BIGINT    NOT NULL,
    `wmbroker_et_mrv_id`  BIGINT    NOT NULL,
    `execution_id`        BIGINT,
    `time`                BIGINT    NOT NULL,
    `num_published`       BIGINT,
    `num_delivered`       BIGINT,
    `last_published`      BIGINT,
    `last_delivered`      BIGINT,
    `num_subscriptions`   BIGINT,
    `num_forwards`        BIGINT,
    `last_forward`        BIGINT,
    `publish_groups`      BIGINT,
    `subscribe_groups`    BIGINT,
    INDEX `wmbroker_et_ts_index1`(`time`),
    INDEX `wmbroker_et_ts_index2`(`execution_id`),
    INDEX `ref98141`(`wmbroker_et_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`wmbroker_et_mrv_id`)
    REFERENCES `wmbroker_et_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `wmis_server_mrv`(
    `id`                BIGINT          AUTO_INCREMENT,
    `host`              VARCHAR(255)    NOT NULL,
    `port`              BIGINT          NOT NULL,
    `time`              BIGINT          NOT NULL,
    `curr_sys_threads`  BIGINT          NOT NULL,
    `peak_sys_threads`  BIGINT          NOT NULL,
    `curr_svc_threads`  BIGINT          NOT NULL,
    `peak_svc_threads`  BIGINT          NOT NULL,
    `curr_tot_sess`     BIGINT          NOT NULL,
    `peak_tot_sess`     BIGINT          NOT NULL,
    `curr_lic_sess`     BIGINT          NOT NULL,
    `peak_lic_sess`     BIGINT          NOT NULL,
    `completed_reqs`    BIGINT          NOT NULL,
    `avg_req_time`      BIGINT          NOT NULL,
    `tot_avg_req_time`  BIGINT          NOT NULL,
    `svc_err_count`     BIGINT          NOT NULL,
    `start_req_rate`    BIGINT          NOT NULL,
    `end_req_rate`      BIGINT          NOT NULL,
    `tot_jvm_mem`       BIGINT          NOT NULL,
    `used_jvm_mem`      BIGINT          NOT NULL,
    `free_jvm_mem`      BIGINT          NOT NULL,
    `uptime`            BIGINT          NOT NULL,
    `tot_invoked`       BIGINT          NOT NULL,
    `cached_svc`        BIGINT          NOT NULL,
    `prefetched_svc`    BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    UNIQUE INDEX `wmis_server_mrv_uni`(`host`, `port`),
    INDEX `wmis_server_mrv_index1`(`time`)
)ENGINE=INNODB
;



CREATE TABLE `wmis_server_ts`(
    `idx`                 BIGINT    NOT NULL,
    `wmis_server_mrv_id`  BIGINT    NOT NULL,
    `execution_id`        BIGINT,
    `time`                BIGINT    NOT NULL,
    `curr_sys_threads`    BIGINT    NOT NULL,
    `peak_sys_threads`    BIGINT    NOT NULL,
    `curr_svc_threads`    BIGINT    NOT NULL,
    `peak_svc_threads`    BIGINT    NOT NULL,
    `curr_tot_sess`       BIGINT    NOT NULL,
    `peak_tot_sess`       BIGINT    NOT NULL,
    `curr_lic_sess`       BIGINT    NOT NULL,
    `peak_lic_sess`       BIGINT    NOT NULL,
    `completed_reqs`      BIGINT    NOT NULL,
    `avg_req_time`        BIGINT    NOT NULL,
    `tot_avg_req_time`    BIGINT    NOT NULL,
    `svc_err_count`       BIGINT    NOT NULL,
    `start_req_rate`      BIGINT    NOT NULL,
    `end_req_rate`        BIGINT    NOT NULL,
    `tot_jvm_mem`         BIGINT    NOT NULL,
    `used_jvm_mem`        BIGINT    NOT NULL,
    `free_jvm_mem`        BIGINT    NOT NULL,
    `uptime`              BIGINT    NOT NULL,
    `tot_invoked`         BIGINT    NOT NULL,
    `cached_svc`          BIGINT    NOT NULL,
    `prefetched_svc`      BIGINT    NOT NULL,
    INDEX `wmis_server_ts_index1`(`time`),
    INDEX `wmis_server_ts_index2`(`execution_id`),
    INDEX `ref86125`(`wmis_server_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`wmis_server_mrv_id`)
    REFERENCES `wmis_server_mrv`(`id`)
)ENGINE=INNODB
;



CREATE TABLE `wmis_service_mrv`(
    `id`                  BIGINT          AUTO_INCREMENT,
    `wmis_server_mrv_id`  BIGINT          NOT NULL,
    `service`             VARCHAR(255)    NOT NULL,
    `time`                BIGINT          NOT NULL,
    `invoked`             BIGINT          NOT NULL,
    PRIMARY KEY (`id`), 
    INDEX `wmis_service_mrv_index1`(`time`),
    UNIQUE INDEX `wmis_service_mrv_uni`(`wmis_server_mrv_id`, `service`),
    INDEX `ref86127`(`wmis_server_mrv_id`), 
    FOREIGN KEY (`wmis_server_mrv_id`)
    REFERENCES `wmis_server_mrv`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;



CREATE TABLE `wmis_service_ts`(
    `idx`                  BIGINT    NOT NULL,
    `wmis_service_mrv_id`  BIGINT    NOT NULL,
    `execution_id`         BIGINT,
    `time`                 BIGINT    NOT NULL,
    `invoked`              BIGINT    NOT NULL,
    INDEX `wmis_service_ts_index1`(`time`),
    INDEX `wmis_service_ts_index2`(`execution_id`),
    INDEX `ref89128`(`wmis_service_mrv_id`),
    FOREIGN KEY (`execution_id`)
    REFERENCES `execution`(`id`) ON DELETE CASCADE,
    FOREIGN KEY (`wmis_service_mrv_id`)
    REFERENCES `wmis_service_mrv`(`id`)
)ENGINE=INNODB
;

CREATE TABLE `execution_note`(
`execution_id` BIGINT   NOT NULL, 
`note`         LONGTEXT NOT NULL, 
PRIMARY KEY (`execution_id`), 
FOREIGN KEY (`execution_id`)
REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;

CREATE TABLE `person`(
`id`       BIGINT      AUTO_INCREMENT, 
`username` VARCHAR(32) NOT NULL, 
PRIMARY KEY (`id`), 
UNIQUE INDEX `person_username`(`username`)
)ENGINE=INNODB
;

CREATE TABLE `execution_lock` (
`execution_id` BIGINT   NOT NULL, 
`person_id`    BIGINT   NOT NULL, 
`time`         BIGINT   NOT NULL,
PRIMARY KEY (`execution_id`), 
FOREIGN KEY (`execution_id`)
REFERENCES `execution`(`id`), 
FOREIGN KEY (`person_id`)
REFERENCES `person` (`id`)
)ENGINE=INNODB
;

CREATE TABLE `execution_label` (
`execution_id` BIGINT   NOT NULL, 
`label`        TEXT     NOT NULL, 
PRIMARY KEY (`execution_id`), 
FOREIGN KEY (`execution_id`)
REFERENCES `execution`(`id`) ON DELETE CASCADE
)ENGINE=INNODB
;

CREATE VIEW SCENARIO_EXECUTIONS_SUBQUERY_ONE AS
SELECT sue.execution_id, app.id, app.uniqueid, app.display, app.project_id, sue.expiration
	FROM suite_execution sue, appmodelitem app
	WHERE sue.appmodelitem_id = app.id
;
    
CREATE VIEW SCENARIO_EXECUTIONS_SUBQUERY_TWO AS
SELECT el.execution_id, p.username, el.time
	FROM execution_lock el, person p
	WHERE el.person_id = p.id
;

CREATE VIEW SCENARIO_EXECUTIONS
(EXECUTION_ID, 
LABEL, 
LOCKBY, 
LOCKDATE,
NOTES_PK,
PROJECT_PK,
SUITE_PK,
SUITE_ID,
SUITE_NAME,
SCENARIO_NAME,
SCENARIO_ID,
START_TIME,
END_TIME,
STATUS,
EXPIRES,
ROOT_EXEC_ID) AS
SELECT sce.execution_id, l.label, u.username, u.time, n.execution_id, t.project_id, t.id, t.uniqueid, t.display, s.display, s.uniqueid, e.start_time, e.end_time, (SELECT display FROM status WHERE id = e.status_id), t.expiration, e.root_id
FROM scenario s, scenario_execution sce, execution e
LEFT OUTER JOIN execution_label l ON e.id = l.execution_id
LEFT OUTER JOIN SCENARIO_EXECUTIONS_SUBQUERY_ONE t ON e.id = t.execution_id
LEFT OUTER JOIN SCENARIO_EXECUTIONS_SUBQUERY_TWO u ON e.id = u.execution_id
LEFT OUTER JOIN execution_note n ON e.id = n.execution_id
WHERE e.id = sce.execution_id AND sce.scenario_id = s.id
;


CREATE VIEW TESTER_PERF_MRV
(ID, NAME, GUID, TIME) AS
select a.ID, a.display, p.uniqueid as guid, 0 as time
from appmodelitem a, project p
where a.project_id = p.id
;

-- Flex Stored Procedures
DELIMITER $$

CREATE PROCEDURE `INSERT_FLEX_COL`
  (
    OUT p_PK     BIGINT,
    IN  p_METHOD BIGINT,
    IN  p_DATA   VARCHAR(255) )
BEGIN
   DECLARE EXIT HANDLER FOR SQLSTATE '23000' SET p_PK = ( SELECT `PK` FROM `FLEX_COL` WHERE `METHOD` = p_METHOD AND `DATA` = p_DATA );
   INSERT
     INTO FLEX_COL
    ( `METHOD`, `DATA`
    ) VALUES
    ( p_METHOD, p_DATA
    );
   SET p_PK = LAST_INSERT_ID();
END $$

CREATE PROCEDURE `INSERT_FLEX_DOUBLE`
  (
    OUT p_PK    BIGINT,
    IN  p_ROW   BIGINT,
    IN  p_EVENT BIGINT,
    IN  p_DATA  DOUBLE )
BEGIN
   INSERT
     INTO FLEX_DOUBLE
    ( `ROW_`, `EVENT`, `DATA`
    ) VALUES
    ( p_ROW, p_EVENT, p_DATA
    );
   SET p_PK = LAST_INSERT_ID();
END $$

CREATE PROCEDURE `INSERT_FLEX_EVENT`
  (
    OUT p_PK       BIGINT,
    IN  p_TIME     BIGINT,
    IN  p_INSTANCE BIGINT 
  )
BEGIN
   INSERT INTO FLEX_EVENT
    ( MILLIS_1970_UTC, INSTANCE
    ) VALUES
    ( p_TIME, p_INSTANCE
    );
   SET p_PK = LAST_INSERT_ID();
END $$

CREATE PROCEDURE `INSERT_FLEX_LONG`
  (
    OUT p_PK    BIGINT,
    IN  p_ROW   BIGINT,
    IN  p_EVENT BIGINT,
    IN  p_DATA  BIGINT )
BEGIN
   INSERT
     INTO FLEX_LONG
    ( `ROW_`, `EVENT`, `DATA`
    ) VALUES
    ( p_ROW, p_EVENT, p_DATA
    );
   SET p_PK = LAST_INSERT_ID();
END $$

CREATE PROCEDURE `INSERT_FLEX_METHOD`
  (
    OUT p_PK    BIGINT,
    IN  p_TYPE  BIGINT,
    IN  p_DATA  VARCHAR(255) )
BEGIN
   DECLARE EXIT HANDLER FOR SQLSTATE '23000' SET p_PK = ( SELECT `PK` FROM FLEX_METHOD WHERE p_TYPE = `TYPE` AND p_DATA = `DATA` );
   INSERT INTO FLEX_METHOD
    ( `TYPE`, `DATA`
    ) VALUES
    ( p_TYPE, p_DATA
    );
   SET p_PK = LAST_INSERT_ID();
END $$

CREATE PROCEDURE `INSERT_FLEX_ROW`
  (
    OUT p_PK   BIGINT,
    IN  p_COL  BIGINT,
    IN  p_DATA VARCHAR(255) )
BEGIN
   DECLARE EXIT HANDLER FOR SQLSTATE '23000' SET p_PK = ( SELECT `PK` FROM FLEX_ROW WHERE p_COL = `COL` AND p_DATA = `DATA` );
   INSERT
     INTO FLEX_ROW
    ( `COL` , `DATA`
    ) VALUES
    ( p_COL , p_DATA
    );
   SET p_PK = LAST_INSERT_ID();
END $$

CREATE PROCEDURE `INSERT_FLEX_TYPE`
  (
    OUT p_PK   BIGINT,
    IN  p_DATA VARCHAR(255)
  )
BEGIN
   DECLARE EXIT HANDLER FOR SQLSTATE '23000' SET p_PK = ( SELECT `PK` FROM FLEX_TYPE WHERE p_DATA = `DATA` );
   INSERT INTO FLEX_TYPE
    ( `DATA`
    ) VALUES
    ( p_DATA
    );
   SET p_PK = LAST_INSERT_ID();
END $$

DELIMITER ;  

INSERT INTO db_details VALUES
   ( now(), 'schema.version.number','1.9.24.f');

commit;
